@@ -4,12 +4,14 @@
 #' Mutate a data frame by the mutateTerms.  Accepts arbitrary text as
 #' mutateTerms to allow forms such as "Sepal.Length >= 2 * Sepal.Width".
 #' Terms are vectors or lists of the form "lhs := rhs".
+#' Semantics are: terms are evaluated left to right if mutate_nse_split_terms==TRUE (the default).
 #'
 #' @seealso \code{\link{mutate_se}}, \code{\link[dplyr]{mutate}}, \code{\link[dplyr]{mutate_at}}, \code{\link[wrapr]{:=}}
 #'
 #' @param .data data.frame
 #' @param ... stringified expressions to mutate by.
-#' @param env environment to work in.
+#' @param mutate_nse_split_terms logical, if TRUE into separate mutates (if FALSE instead, pass all at once to dplyr).
+#' @param mutate_nse_env environment to work in.
 #' @return .data with altered columns.
 #'
 #' @examples
@@ -28,13 +30,15 @@
 #'
 #' @export
 #'
-mutate_nse <- function(.data, ...,  env = parent.frame()) {
+mutate_nse <- function(.data, ...,
+                       mutate_nse_split_terms = TRUE,
+                       mutate_nse_env = parent.frame()) {
   # convert char vector into spliceable vector
   # from: https://github.com/tidyverse/rlang/issues/116
   mutateTerms <- substitute(list(...))
   # mutateTerms is a list of k+1 items, first is "list" the rest are captured expressions
   res <- .data
-  len <- length(mutateTerms)
+  len <- length(mutateTerms) # first slot is "list"
   if(len>1) {
     lhs <- vector(len-1, mode='list')
     rhs <- vector(len-1, mode='list')
@@ -43,10 +47,11 @@ mutate_nse <- function(.data, ...,  env = parent.frame()) {
       if((length(ei)!=3)||(as.character(ei[[1]])!=':=')) {
         stop("mutate_nse terms must be of the form: sym := expr")
       }
-      lhs[[i-1]] <- as.character(prep_deref(ei[[2]], env))
-      rhs[[i-1]] <- deparse(prep_deref(ei[[3]], env))
+      lhs[[i-1]] <- as.character(prep_deref(ei[[2]], mutate_nse_env))
+      rhs[[i-1]] <- deparse(prep_deref(ei[[3]], mutate_nse_env))
     }
-    res <- mutate_se(res, lhs := rhs, env=env)
+    res <- mutate_se(res, lhs := rhs, splitTerms = mutate_nse_split_terms,
+                     env=mutate_nse_env)
   }
   res
 }
